@@ -2,7 +2,7 @@
 #
 # django-codenerix
 #
-# Copyright 2017 Centrologic Computational Logistic Center S.L.
+# Codenerix GNU
 #
 # Project URL : http://www.codenerix.com
 #
@@ -18,6 +18,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
 import re
 import random
 import hashlib
@@ -29,10 +30,10 @@ import imghdr
 
 from django import forms
 from django.urls import reverse, resolve
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.core.files.base import File
 from django.utils import formats
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.utils.html import escapejs
 from django.conf import settings
 from django.utils.translation import get_language
@@ -103,22 +104,22 @@ class StaticSelectMulti(forms.widgets.Select):
             if hasattr(self, "field"):
                 for (key, label) in self.field.choices:
                     if value == key:
-                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_text(label))))
-                    init += u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_text(label)))
+                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_str(label))))
+                    init += u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_str(label)))
             elif type(self.choices) == list:
 
                 for (key, label) in self.choices:
                     if value == key:
-                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_text(label))))
-                    init += u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_text(label)))
+                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_str(label))))
+                    init += u'{{"id":"{0}","label":"{1}"}},'.format(key, escapejs(smart_str(label)))
             else:
                 # FORCE RELOAD DATAS
                 elements = self.choices.queryset
                 elements._result_cache = None
                 for choice in elements:
-                    init += u'{{"id":"{0}","label":"{1}"}},'.format(choice.pk, escapejs(smart_text(choice)))
+                    init += u'{{"id":"{0}","label":"{1}"}},'.format(choice.pk, escapejs(smart_str(choice)))
                     if value and (type(value) is list) and (choice.pk in value):
-                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(int(choice.pk), escapejs(smart_text(choice))))
+                        valuejs.append(u'{{"id":"{0}","label":"{1}"}},'.format(int(choice.pk), escapejs(smart_str(choice))))
         else:
             init = "getForeignKeys(http,'{0}',amc_items,{{".format(vurl)
             comma = False
@@ -196,7 +197,7 @@ class StaticSelect(forms.widgets.Select):
         vid = attrs.get('id', 'id_{0}'.format(name))
         vstyle = attrs.get('style', '')
         ngreadonly = attrs.get('ng-readonly', '')
-        vform = smart_text(self.form_name)
+        vform = smart_str(self.form_name)
         placeholder = escapejs(_('Select an option'))
         is_multiple = hasattr(self, "multiple") and self.multiple
 
@@ -243,13 +244,13 @@ class StaticSelect(forms.widgets.Select):
             for (key, label) in self.field.choices:
                 if value == key:
                     ini = index
-                html += u"{{'id':'{0}','label':'{1}'}},".format(key, escapejs(smart_text(label)))
+                html += u"{{'id':'{0}','label':'{1}'}},".format(key, escapejs(smart_str(label)))
                 index += 1
         elif type(self.choices) == list:
             for (key, label) in self.choices:
                 if value == key:
                     ini = index
-                html += u"{{'id':'{0}','label':'{1}'}},".format(key, escapejs(smart_text(label)))
+                html += u"{{'id':'{0}','label':'{1}'}},".format(key, escapejs(smart_str(label)))
                 index += 1
         else:
             if not is_multiple:
@@ -258,7 +259,7 @@ class StaticSelect(forms.widgets.Select):
             for choice in self.choices.queryset:
                 if value == choice.pk:  # only not multiple
                     ini = index
-                html += u"{{'id':'{0}','label':'{1}'}},".format(choice.pk, escapejs(smart_text(choice)))
+                html += u"{{'id':'{0}','label':'{1}'}},".format(choice.pk, escapejs(smart_str(choice)))
                 if value and (type(value) is list) and (str(choice.pk) in value):
                     list_value.append({'id': int(choice.pk), 'label': str(choice)})
                 index += 1
@@ -393,7 +394,7 @@ class DynamicSelect(DynamicSelectInputWidget, forms.widgets.Select):
         vmodel = self.field_name
         vid = attrs.get('id', 'id_{0}'.format(name))
         vstyle = attrs.get('style', '')
-        vform = smart_text(self.form_name)
+        vform = smart_str(self.form_name)
         vurl = reverse(self.autofill_url, kwargs={'search': 'a'})[:-1]
         # Get access to the get_label() method and request for the label of the bound input
         if value:
@@ -520,20 +521,28 @@ class FileAngularInput(forms.widgets.FileInput):
         })
 
         # Hacer link hacia el archivo
-        button = super(FileAngularInput, self).render(name, value, attrs=attrs)
-        if value and type(value) != dict:
-            if imghdr.what("{}/{}".format(settings.MEDIA_ROOT, value)) is not None:
-                image = u'<img src="{0}{1}" style="max-height:75px; max-width:150px;" />'.format(settings.MEDIA_URL, value)
-                link = u'<a href="{0}{1}" target="_blank">{2}</a>'.format(settings.MEDIA_URL, value, image)
-
-                html = '<div class="row">'
-                html += '   <div class="col-md-6">{}</div>'.format(button)
-                html += '   <div class="col-md-6">{}</div>'.format(link)
-                html += '</div>'
+        if value and not isinstance(value, dict):
+            path_image = "{}/{}".format(settings.MEDIA_ROOT, value)
+            if not os.path.exists(path_image):
+                value = None
+                attrs.pop('value')
+                button = super(FileAngularInput, self).render(name, value, attrs=attrs)
+                html = button
             else:
-                link = u'<br /><a href="{0}{1}" target="_blank">{2}</a><br />'.format(settings.MEDIA_URL, value, value)
-                html = link + button
+                button = super(FileAngularInput, self).render(name, value, attrs=attrs)
+                if imghdr.what(path_image) is not None:
+                    image = u'<img src="{0}{1}" style="max-height:75px; max-width:150px;" />'.format(settings.MEDIA_URL, value)
+                    link = u'<a href="{0}{1}" target="_blank">{2}</a>'.format(settings.MEDIA_URL, value, image)
+
+                    html = '<div class="row">'
+                    html += '   <div class="col-md-6">{}</div>'.format(button)
+                    html += '   <div class="col-md-6">{}</div>'.format(link)
+                    html += '</div>'
+                else:
+                    link = u'<br /><a href="{0}{1}" target="_blank">{2}</a><br />'.format(settings.MEDIA_URL, value, value)
+                    html = link + button
         else:
+            button = super(FileAngularInput, self).render(name, value, attrs=attrs)
             html = button
 
         return html
@@ -736,7 +745,7 @@ class WysiwygAngularRender(forms.widgets.HiddenInput):
         editors['preview'] = _("Preview")
         editors_list = []
         for keyarg in editors.keys():
-            editors_list.append(u"\"{0}\":{{\"key\":\"{0}\",\"name\":\"{1}\"}}".format(keyarg, smart_text(editors[keyarg])))
+            editors_list.append(u"\"{0}\":{{\"key\":\"{0}\",\"name\":\"{1}\"}}".format(keyarg, smart_str(editors[keyarg])))
         editors_json = u"{" + ",".join(editors_list) + "}"
 
         # Detect if this field is required
